.. PyCompadre documentation master file, created by
   sphinx-quickstart on Tue Oct  5 10:33:34 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PyCOMPADRE Documentation
======================================

.. toctree::
   :maxdepth: 3

   pycompadre_module
   Basic Example <example.rst>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
